@@ -8,8 +8,8 @@ from godot_rl.core.utils import lod_to_dol
 
 
 class StableBaselinesGodotEnv(VecEnv):
-    def __init__(self, port=10008, seed=0):
-        self.env = GodotEnv(port=port, seed=seed)
+    def __init__(self, env_path=None, **kwargs):
+        self.env = GodotEnv(env_path=env_path, **kwargs)
         self._check_valid_action_space()
 
     def _check_valid_action_space(self):
@@ -75,7 +75,7 @@ class StableBaselinesGodotEnv(VecEnv):
 
 def stable_baselines_training(args, extras):
     # TODO: Add cla etc for sb3
-    env = StableBaselinesGodotEnv()
+    env = StableBaselinesGodotEnv(env_path=args.env_path)
 
     model = PPO(
         "MultiInputPolicy",
